@@ -6,7 +6,7 @@ from .base_interceptor import BaseInterceptor
 
 class BaseStub:
     def __init__(self, channel, stub, allure=None):
-        self.channel = intercept_channel(channel, BaseInterceptor(allure))
+        self.channel = intercept_channel(channel, BaseInterceptor(channel, allure))
         self.stub = stub(self.channel)
 
 
